#!/bin/env python
# UTF-32-LE Python File with a BOM

## @brief A UTF-32LE File identified by BOM.
#
#This doesn't have much to it, but it identifies itself
#using a BOM rather than a coding line.
#
# @note
#	See how doxypypy converts this note and the
#	following warning.
#
# @warning
#	Be sure to save this file in the proper encoding.
#
# @namespace sample_utf32lebom

print('Hello, I am in UTF-32LE encoding.')
