#!/bin/env python
# UTF-16-LE Python File with a BOM

"""
A UTF-16LE File identified by BOM.

This doesn't have much to it, but it identifies itself
using a BOM rather than a coding line.

Note:
	See how doxypypy converts this note and the
	following warning.

Warning:
	Be sure to save this file in the proper encoding.
"""
print('Hello, I am in UTF-16LE encoding.')
